import logging

# Set up logging
logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')

# Version of the cabdimajiid module
__version__ = "1.0.0"

# AI/ML Frameworks
try:
    import tensorflow as tf
    import torch
    import sklearn
    import keras
    import fastai
    import cv2  # OpenCV
    logging.info("AI/ML frameworks imported successfully.")
except ImportError as e:
    logging.error("Failed to import AI/ML frameworks: %s", e)

# Non-AI Frameworks
try:
    import flask
    import django
    import pandas as pd
    import numpy as np
    import matplotlib.pyplot as plt
    import sqlalchemy
    import pytest
    logging.info("Non-AI frameworks imported successfully.")
except ImportError as e:
    logging.error("Failed to import Non-AI frameworks: %s", e)

# Mobile App Frameworks
try:
    import kivy
    import toga
    logging.info("Mobile frameworks imported successfully.")
except ImportError as e:
    logging.error("Failed to import Mobile frameworks: %s", e)

# Desktop App Frameworks
try:
    import PyQt5
    import PySide6
    import wx
    logging.info("Desktop frameworks imported successfully.")
except ImportError as e:
    logging.error("Failed to import Desktop frameworks: %s", e)

# Packaging Tools
try:
    import buildozer
    import PyInstaller
    logging.info("Packaging tools imported successfully.")
except ImportError as e:
    logging.error("Failed to import Packaging tools: %s", e)

class Frameworks:
    def __init__(self):
        self.ai_frameworks = {
            'TensorFlow': tf,
            'PyTorch': torch,
            'Scikit-learn': sklearn,
            'Keras': keras,
            'FastAI': fastai,
            'OpenCV': cv2
        }
        self.non_ai_frameworks = {
            'Flask': flask,
            'Django': django,
            'Pandas': pd,
            'NumPy': np,
            'Matplotlib': plt,
            'SQLAlchemy': sqlalchemy,
            'Pytest': pytest
        }
        self.mobile_frameworks = {
            'Kivy': kivy,
            'Toga': toga
        }
        self.desktop_frameworks = {
            'PyQt5': PyQt5,
            'PySide6': PySide6,
            'wxPython': wx
        }

    def print_ai_versions(self):
        for name, framework in self.ai_frameworks.items():
            if name == 'TensorFlow':
                logging.info(f"{name} version: {framework.__version__}")
            elif name == 'PyTorch':
                logging.info(f"{name} version: {framework.__version__}")
            elif name == 'OpenCV':
                logging.info(f"{name} version: {framework.__version__}")

    def print_non_ai_versions(self):
        for name, framework in self.non_ai_frameworks.items():
            if name == 'Pandas':
                logging.info(f"{name} version: {framework.__version__}")

# Optional: Run some initial checks on imports
def run_initial_checks():
    try:
        frameworks = Frameworks()
        frameworks.print_ai_versions()
        frameworks.print_non_ai_versions()
    except Exception as e:
        logging.error("An error occurred while running initial checks: %s", e)

# Run initial checks upon import
run_initial_checks()
